#Andrew Ruis ENA plots replication in rENA
require("rENA")

#Read data for figures 5 and 6 (sub with datafile location online)
####replace with your data location###
load("C:/Users/ndporter/Google Drive/Consults Meetings Speakers/viral networks workshop/Ruis/NutritionDefinitions01.RData")

#Define decade groupings from Ruis Figures 5 and 6
figData = cut(NutritionDefinitions01.csv$enadata$units$Decade,breaks=c(1799,1870,1930,1960,2000),include_lowest=TRUE)
figData.integer.vector <- unclass(figData)

#define groups based on year of definition
group1.points = NutritionDefinitions01.csv$points.rotated[figData.integer.vector == 1,]
group2.points = NutritionDefinitions01.csv$points.rotated[figData.integer.vector == 2,]
group3.points = NutritionDefinitions01.csv$points.rotated[figData.integer.vector == 3,]
group4.points = NutritionDefinitions01.csv$points.rotated[figData.integer.vector == 4,]

#define unit names
unitNames = NutritionDefinitions01.csv$enadata$unit.names

#line weights and means for year-delimited network plots
group1.lineweights = NutritionDefinitions01.csv$line.weights[figData.integer.vector==1,]
group1.mean = colMeans(group1.lineweights)
group2.lineweights = NutritionDefinitions01.csv$line.weights[figData.integer.vector==2,]
group2.mean = colMeans(group2.lineweights)
group3.lineweights = NutritionDefinitions01.csv$line.weights[figData.integer.vector==3,]
group3.mean = colMeans(group3.lineweights)
group4.lineweights = NutritionDefinitions01.csv$line.weights[figData.integer.vector==4,]
group4.mean = colMeans(group4.lineweights)

#Plot means and CIs for groups of years (Figure 6)
plot = ena.plot(NutritionDefinitions01.csv)
plot = ena.plot.group(plot, points = group1.points,labels="1800-1869",colors="green",confidence.interval="box")
plot = ena.plot.group(plot, points = group2.points,labels="1870-1929",colors="orange",confidence.interval="box")
plot = ena.plot.group(plot, points = group3.points,labels="1930-1959",colors="blue",confidence.interval="box")
plot = ena.plot.group(plot, points = group4.points,labels="1960-1999",colors="purple",confidence.interval="box")
print(plot)

##plot networks for Figure 5 
#1800-1869
plot = ena.plot(NutritionDefinitions01.csv)
plot = ena.plot.network(plot, network=group1.mean)
print(plot)
#1870-1929
plot = ena.plot(NutritionDefinitions01.csv)
plot = ena.plot.network(plot, network=group2.mean)
print(plot)
#1930-1959
plot = ena.plot(NutritionDefinitions01.csv)
plot = ena.plot.network(plot, network=group3.mean)
print(plot)
#1960-1999
plot = ena.plot(NutritionDefinitions01.csv)
plot = ena.plot.network(plot, network=group4.mean)
print(plot)

###Create networks with source type variable and plots

#Read data for figure 7
load("C:/Users/ndporter/Google Drive/Consults Meetings Speakers/viral networks workshop/Ruis/NutritionDefinitions02.RData")

#convert source type to integer
figData.integer.vector <- unclass(NutritionDefinitions02$enadata$units$SourceType)

#define groups based on source type
group1.points = NutritionDefinitions02$points.rotated[figData.integer.vector == 1,]
group2.points = NutritionDefinitions02$points.rotated[figData.integer.vector == 2,]
group3.points = NutritionDefinitions02$points.rotated[figData.integer.vector == 3,]
group4.points = NutritionDefinitions02$points.rotated[figData.integer.vector == 4,]

#define unit names
unitNames = NutritionDefinitions02$enadata$unit.names

#line weights and means for year-delimited network plots
group1.lineweights = NutritionDefinitions02$line.weights[figData.integer.vector==1,]
group1.mean = colMeans(group1.lineweights)
group2.lineweights = NutritionDefinitions02$line.weights[figData.integer.vector==2,]
group2.mean = colMeans(group2.lineweights)
group3.lineweights = NutritionDefinitions02$line.weights[figData.integer.vector==3,]
group3.mean = colMeans(group3.lineweights)
group4.lineweights = NutritionDefinitions02$line.weights[figData.integer.vector==4,]
group4.mean = colMeans(group4.lineweights)

##plot networks for Figure 7
#Articles
plot = ena.plot(NutritionDefinitions02)
plot = ena.plot.network(plot, network=group1.mean)
print(plot)
#Government Reports (not inlcuded in figure because of low N)
plot = ena.plot(NutritionDefinitions02)
plot = ena.plot.network(plot, network=group2.mean)
print(plot)
#Monographs
plot = ena.plot(NutritionDefinitions02)
plot = ena.plot.network(plot, network=group3.mean)
print(plot)
#Reference Works
plot = ena.plot(NutritionDefinitions02)
plot = ena.plot.network(plot, network=group4.mean)
print(plot)

#Group means and CIs
plot = ena.plot(NutritionDefinitions02)
plot = ena.plot.group(plot, points = group1.points,labels="Articles",colors="purple",confidence.interval="box")
plot = ena.plot.group(plot, points = group3.points,labels="Monographs",colors="blue",confidence.interval="box")
plot = ena.plot.group(plot, points = group4.points,labels="Reference Works",colors="green",confidence.interval="box")
print(plot)

###Create difference plot distinguishing Lusk-citing definitions from others

#Read data for figure 8
load("C:/Users/ndporter/Google Drive/Consults Meetings Speakers/viral networks workshop/Ruis/NutritionDefinitions03.RData")

#convert Lusk marker to integer
figData.integer.vector <- unclass(NutritionDefinitions03$enadata$units$Lusk.Effect)

#define groups based on whether they cite Lusk
group1.points = NutritionDefinitions03$points.rotated[figData.integer.vector == 1,]
group2.points = NutritionDefinitions03$points.rotated[figData.integer.vector == 0,]

#define unit names
unitNames = NutritionDefinitions03$enadata$unit.names

#line weights and means for lusk/not network plots
group1.lineweights = NutritionDefinitions03$line.weights[figData.integer.vector==1,]
group1.mean = colMeans(group1.lineweights)
group2.lineweights = NutritionDefinitions03$line.weights[figData.integer.vector==0,]
group2.mean = colMeans(group2.lineweights)

#Subtract and plot
plot = ena.plot(NutritionDefinitions03)
plot = ena.plot.group(plot, points=group1.points,colors="blue",confidence.interval="box")
plot = ena.plot.group(plot, points=group2.points,colors="red",confidence.interval="box")
subtracted.network=group1.mean-group2.mean
plot=ena.plot.network(plot, network=subtracted.network)
print(plot)